@@ -16,7 +16,7 @@ def do_job(n_days=7):
         if email_list is not None and len(email_list) > 0:
             yag = yagmail.SMTP('858776278@qq.com', 'uurpxchfekfebahj', host='smtp.qq.com', port='465')
             yag.send(email_list, '指数跟踪', contents='数据获取异常:' + str(e))
-        print(e)
+        raise e
 
 
 def persist_lxr_data_hand(cookie):
